@@ -104,7 +104,7 @@ public class XmlReader implements RunnableSource {
 		} catch (IOException e) {
 			throw new OsmosisRuntimeException("Unable to read XML file " + file + ".", e);
 		} finally {
-			sink.release();
+			sink.close();
 			
 			if (inputStream != null) {
 				try {
